pub struct LiquidityTournament {
pub gauge_threshold_percent: u64,
pub max_positions: u64,
pub max_delegators: u64,
pub delegator_share_percent: u64,
}Fields
gauge_threshold_percent: u64The fraction of gauge votes that an asset must pass to get any rewards.
Takes a value in [0, 100].
max_positions: u64The maximum number of liquidity positions that can receive rewards.
This avoids potential DoS vectors with processing a large number of small positions.
max_delegators: u64The maximum number of delegators that can be rewarded.
Also avoids potential DoS vectors
The share of rewards which will go to delegators, opposed with positions.
Takes a value in [0, 100].